use super::arithmetic_crystal_class::ArithmeticNumber;
use super::hall_symbol::Centering;

pub type Number = i32;
pub type HallNumber = i32;

#[derive(Debug, Clone)]
pub struct HallSymbolEntry {
    pub hall_number: HallNumber,
    pub number: Number,
    pub arithmetic_number: ArithmeticNumber,
    pub setting: &'static str,     // setting
    pub hall_symbol: &'static str, // Hall symbol
    pub hm_short: &'static str,    // HM symbol HallSymbolEntry::new(short)
    pub hm_full: &'static str,     // HM symbol HallSymbolEntry::new(full)
    pub centering: Centering,
}

impl HallSymbolEntry {
    #[allow(clippy::too_many_arguments)]
    const fn new(
        hall_number: HallNumber,
        number: Number,
        arithmetic_number: ArithmeticNumber,
        setting: &'static str,
        hall_symbol: &'static str,
        hm_short: &'static str,
        hm_full: &'static str,
        centering: Centering,
    ) -> Self {
        Self {
            hall_number,
            number,
            arithmetic_number,
            setting,
            hall_symbol,
            hm_short,
            hm_full,
            centering,
        }
    }
}

pub fn hall_symbol_entry(hall_number: HallNumber) -> HallSymbolEntry {
    HALL_SYMBOL_DATABASE[(hall_number - 1) as usize].clone()
}

pub fn iter_hall_symbol_entry() -> impl Iterator<Item = &'static HallSymbolEntry> {
    HALL_SYMBOL_DATABASE.iter()
}

const HALL_SYMBOL_DATABASE: [HallSymbolEntry; 530] = [
    HallSymbolEntry::new(1, 1, 1, "", "P 1", "P 1", "P 1", Centering::P),
    HallSymbolEntry::new(2, 2, 2, "", "-P 1", "P -1", "P -1", Centering::P),
    HallSymbolEntry::new(3, 3, 3, "b", "P 2y", "P 2", "P 1 2 1", Centering::P),
    HallSymbolEntry::new(4, 3, 3, "c", "P 2", "P 2", "P 1 1 2", Centering::P),
    HallSymbolEntry::new(5, 3, 3, "a", "P 2x", "P 2", "P 2 1 1", Centering::P),
    HallSymbolEntry::new(6, 4, 3, "b", "P 2yb", "P 2_1", "P 1 2_1 1", Centering::P),
    HallSymbolEntry::new(7, 4, 3, "c", "P 2c", "P 2_1", "P 1 1 2_1", Centering::P),
    HallSymbolEntry::new(8, 4, 3, "a", "P 2xa", "P 2_1", "P 2_1 1 1", Centering::P),
    HallSymbolEntry::new(9, 5, 4, "b1", "C 2y", "C 2", "C 1 2 1", Centering::C),
    HallSymbolEntry::new(10, 5, 4, "b2", "A 2y", "C 2", "A 1 2 1", Centering::A),
    HallSymbolEntry::new(11, 5, 4, "b3", "I 2y", "C 2", "I 1 2 1", Centering::I),
    HallSymbolEntry::new(12, 5, 4, "c1", "A 2", "C 2", "A 1 1 2", Centering::A),
    HallSymbolEntry::new(13, 5, 4, "c2", "B 2", "C 2", "B 1 1 2", Centering::B),
    HallSymbolEntry::new(14, 5, 4, "c3", "I 2", "C 2", "I 1 1 2", Centering::I),
    HallSymbolEntry::new(15, 5, 4, "a1", "B 2x", "C 2", "B 2 1 1", Centering::B),
    HallSymbolEntry::new(16, 5, 4, "a2", "C 2x", "C 2", "C 2 1 1", Centering::C),
    HallSymbolEntry::new(17, 5, 4, "a3", "I 2x", "C 2", "I 2 1 1", Centering::I),
    HallSymbolEntry::new(18, 6, 5, "b", "P -2y", "P m", "P 1 m 1", Centering::P),
    HallSymbolEntry::new(19, 6, 5, "c", "P -2", "P m", "P 1 1 m", Centering::P),
    HallSymbolEntry::new(20, 6, 5, "a", "P -2x", "P m", "P m 1 1", Centering::P),
    HallSymbolEntry::new(21, 7, 5, "b1", "P -2yc", "P c", "P 1 c 1", Centering::P),
    HallSymbolEntry::new(22, 7, 5, "b2", "P -2yac", "P c", "P 1 n 1", Centering::P),
    HallSymbolEntry::new(23, 7, 5, "b3", "P -2ya", "P c", "P 1 a 1", Centering::P),
    HallSymbolEntry::new(24, 7, 5, "c1", "P -2a", "P c", "P 1 1 a", Centering::P),
    HallSymbolEntry::new(25, 7, 5, "c2", "P -2ab", "P c", "P 1 1 n", Centering::P),
    HallSymbolEntry::new(26, 7, 5, "c3", "P -2b", "P c", "P 1 1 b", Centering::P),
    HallSymbolEntry::new(27, 7, 5, "a1", "P -2xb", "P c", "P b 1 1", Centering::P),
    HallSymbolEntry::new(28, 7, 5, "a2", "P -2xbc", "P c", "P n 1 1", Centering::P),
    HallSymbolEntry::new(29, 7, 5, "a3", "P -2xc", "P c", "P c 1 1", Centering::P),
    HallSymbolEntry::new(30, 8, 6, "b1", "C -2y", "C m", "C 1 m 1", Centering::C),
    HallSymbolEntry::new(31, 8, 6, "b2", "A -2y", "C m", "A 1 m 1", Centering::A),
    HallSymbolEntry::new(32, 8, 6, "b3", "I -2y", "C m", "I 1 m 1", Centering::I),
    HallSymbolEntry::new(33, 8, 6, "c1", "A -2", "C m", "A 1 1 m", Centering::A),
    HallSymbolEntry::new(34, 8, 6, "c2", "B -2", "C m", "B 1 1 m", Centering::B),
    HallSymbolEntry::new(35, 8, 6, "c3", "I -2", "C m", "I 1 1 m", Centering::I),
    HallSymbolEntry::new(36, 8, 6, "a1", "B -2x", "C m", "B m 1 1", Centering::B),
    HallSymbolEntry::new(37, 8, 6, "a2", "C -2x", "C m", "C m 1 1", Centering::C),
    HallSymbolEntry::new(38, 8, 6, "a3", "I -2x", "C m", "I m 1 1", Centering::I),
    HallSymbolEntry::new(39, 9, 6, "b1", "C -2yc", "C c", "C 1 c 1", Centering::C),
    HallSymbolEntry::new(40, 9, 6, "b2", "A -2yab", "C c", "A 1 n 1", Centering::A),
    HallSymbolEntry::new(41, 9, 6, "b3", "I -2ya", "C c", "I 1 a 1", Centering::I),
    HallSymbolEntry::new(42, 9, 6, "-b1", "A -2ya", "C c", "A 1 a 1", Centering::A),
    HallSymbolEntry::new(43, 9, 6, "-b2", "C -2yac", "C c", "C 1 n 1", Centering::C),
    HallSymbolEntry::new(44, 9, 6, "-b3", "I -2yc", "C c", "I 1 c 1", Centering::I),
    HallSymbolEntry::new(45, 9, 6, "c1", "A -2a", "C c", "A 1 1 a", Centering::A),
    HallSymbolEntry::new(46, 9, 6, "c2", "B -2ab", "C c", "B 1 1 n", Centering::B),
    HallSymbolEntry::new(47, 9, 6, "c3", "I -2b", "C c", "I 1 1 b", Centering::I),
    HallSymbolEntry::new(48, 9, 6, "-c1", "B -2b", "C c", "B 1 1 b", Centering::B),
    HallSymbolEntry::new(49, 9, 6, "-c2", "A -2ab", "C c", "A 1 1 n", Centering::A),
    HallSymbolEntry::new(50, 9, 6, "-c3", "I -2a", "C c", "I 1 1 a", Centering::I),
    HallSymbolEntry::new(51, 9, 6, "a1", "B -2xb", "C c", "B b 1 1", Centering::B),
    HallSymbolEntry::new(52, 9, 6, "a2", "C -2xac", "C c", "C n 1 1", Centering::C),
    HallSymbolEntry::new(53, 9, 6, "a3", "I -2xc", "C c", "I c 1 1", Centering::I),
    HallSymbolEntry::new(54, 9, 6, "-a1", "C -2xc", "C c", "C c 1 1", Centering::C),
    HallSymbolEntry::new(55, 9, 6, "-a2", "B -2xab", "C c", "B n 1 1", Centering::B),
    HallSymbolEntry::new(56, 9, 6, "-a3", "I -2xb", "C c", "I b 1 1", Centering::I),
    HallSymbolEntry::new(57, 10, 7, "b", "-P 2y", "P 2/m", "P 1 2/m 1", Centering::P),
    HallSymbolEntry::new(58, 10, 7, "c", "-P 2", "P 2/m", "P 1 1 2/m", Centering::P),
    HallSymbolEntry::new(59, 10, 7, "a", "-P 2x", "P 2/m", "P 2/m 1 1", Centering::P),
    HallSymbolEntry::new(
        60,
        11,
        7,
        "b",
        "-P 2yb",
        "P 2_1/m",
        "P 1 2_1/m 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        61,
        11,
        7,
        "c",
        "-P 2c",
        "P 2_1/m",
        "P 1 1 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        62,
        11,
        7,
        "a",
        "-P 2xa",
        "P 2_1/m",
        "P 2_1/m 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(63, 12, 8, "b1", "-C 2y", "C 2/m", "C 1 2/m 1", Centering::C),
    HallSymbolEntry::new(64, 12, 8, "b2", "-A 2y", "C 2/m", "A 1 2/m 1", Centering::A),
    HallSymbolEntry::new(65, 12, 8, "b3", "-I 2y", "C 2/m", "I 1 2/m 1", Centering::I),
    HallSymbolEntry::new(66, 12, 8, "c1", "-A 2", "C 2/m", "A 1 1 2/m", Centering::A),
    HallSymbolEntry::new(67, 12, 8, "c2", "-B 2", "C 2/m", "B 1 1 2/m", Centering::B),
    HallSymbolEntry::new(68, 12, 8, "c3", "-I 2", "C 2/m", "I 1 1 2/m", Centering::I),
    HallSymbolEntry::new(69, 12, 8, "a1", "-B 2x", "C 2/m", "B 2/m 1 1", Centering::B),
    HallSymbolEntry::new(70, 12, 8, "a2", "-C 2x", "C 2/m", "C 2/m 1 1", Centering::C),
    HallSymbolEntry::new(71, 12, 8, "a3", "-I 2x", "C 2/m", "I 2/m 1 1", Centering::I),
    HallSymbolEntry::new(
        72,
        13,
        7,
        "b1",
        "-P 2yc",
        "P 2/c",
        "P 1 2/c 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        73,
        13,
        7,
        "b2",
        "-P 2yac",
        "P 2/c",
        "P 1 2/n 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        74,
        13,
        7,
        "b3",
        "-P 2ya",
        "P 2/c",
        "P 1 2/a 1",
        Centering::P,
    ),
    HallSymbolEntry::new(75, 13, 7, "c1", "-P 2a", "P 2/c", "P 1 1 2/a", Centering::P),
    HallSymbolEntry::new(
        76,
        13,
        7,
        "c2",
        "-P 2ab",
        "P 2/c",
        "P 1 1 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(77, 13, 7, "c3", "-P 2b", "P 2/c", "P 1 1 2/b", Centering::P),
    HallSymbolEntry::new(
        78,
        13,
        7,
        "a1",
        "-P 2xb",
        "P 2/c",
        "P 2/b 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        79,
        13,
        7,
        "a2",
        "-P 2xbc",
        "P 2/c",
        "P 2/n 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        80,
        13,
        7,
        "a3",
        "-P 2xc",
        "P 2/c",
        "P 2/c 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        81,
        14,
        7,
        "b1",
        "-P 2ybc",
        "P 2_1/c",
        "P 1 2_1/c 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        82,
        14,
        7,
        "b2",
        "-P 2yn",
        "P 2_1/c",
        "P 1 2_1/n 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        83,
        14,
        7,
        "b3",
        "-P 2yab",
        "P 2_1/c",
        "P 1 2_1/a 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        84,
        14,
        7,
        "c1",
        "-P 2ac",
        "P 2_1/c",
        "P 1 1 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        85,
        14,
        7,
        "c2",
        "-P 2n",
        "P 2_1/c",
        "P 1 1 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        86,
        14,
        7,
        "c3",
        "-P 2bc",
        "P 2_1/c",
        "P 1 1 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        87,
        14,
        7,
        "a1",
        "-P 2xab",
        "P 2_1/c",
        "P 2_1/b 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        88,
        14,
        7,
        "a2",
        "-P 2xn",
        "P 2_1/c",
        "P 2_1/n 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        89,
        14,
        7,
        "a3",
        "-P 2xac",
        "P 2_1/c",
        "P 2_1/c 1 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        90,
        15,
        8,
        "b1",
        "-C 2yc",
        "C 2/c",
        "C 1 2/c 1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        91,
        15,
        8,
        "b2",
        "-A 2yab",
        "C 2/c",
        "A 1 2/n 1",
        Centering::A,
    ),
    HallSymbolEntry::new(
        92,
        15,
        8,
        "b3",
        "-I 2ya",
        "C 2/c",
        "I 1 2/a 1",
        Centering::I,
    ),
    HallSymbolEntry::new(
        93,
        15,
        8,
        "-b1",
        "-A 2ya",
        "C 2/c",
        "A 1 2/a 1",
        Centering::A,
    ),
    HallSymbolEntry::new(
        94,
        15,
        8,
        "-b2",
        "-C 2yac",
        "C 2/c",
        "C 1 2/n 1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        95,
        15,
        8,
        "-b3",
        "-I 2yc",
        "C 2/c",
        "I 1 2/c 1",
        Centering::I,
    ),
    HallSymbolEntry::new(96, 15, 8, "c1", "-A 2a", "C 2/c", "A 1 1 2/a", Centering::A),
    HallSymbolEntry::new(
        97,
        15,
        8,
        "c2",
        "-B 2ab",
        "C 2/c",
        "B 1 1 2/n",
        Centering::B,
    ),
    HallSymbolEntry::new(98, 15, 8, "c3", "-I 2b", "C 2/c", "I 1 1 2/b", Centering::I),
    HallSymbolEntry::new(
        99,
        15,
        8,
        "-c1",
        "-B 2b",
        "C 2/c",
        "B 1 1 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        100,
        15,
        8,
        "-c2",
        "-A 2ab",
        "C 2/c",
        "A 1 1 2/n",
        Centering::A,
    ),
    HallSymbolEntry::new(
        101,
        15,
        8,
        "-c3",
        "-I 2a",
        "C 2/c",
        "I 1 1 2/a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        102,
        15,
        8,
        "a1",
        "-B 2xb",
        "C 2/c",
        "B 2/b 1 1",
        Centering::B,
    ),
    HallSymbolEntry::new(
        103,
        15,
        8,
        "a2",
        "-C 2xac",
        "C 2/c",
        "C 2/n 1 1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        104,
        15,
        8,
        "a3",
        "-I 2xc",
        "C 2/c",
        "I 2/c 1 1",
        Centering::I,
    ),
    HallSymbolEntry::new(
        105,
        15,
        8,
        "-a1",
        "-C 2xc",
        "C 2/c",
        "C 2/c 1 1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        106,
        15,
        8,
        "-a2",
        "-B 2xab",
        "C 2/c",
        "B 2/n 1 1",
        Centering::B,
    ),
    HallSymbolEntry::new(
        107,
        15,
        8,
        "-a3",
        "-I 2xb",
        "C 2/c",
        "I 2/b 1 1",
        Centering::I,
    ),
    HallSymbolEntry::new(108, 16, 9, "", "P 2 2", "P 2 2 2", "P 2 2 2", Centering::P),
    HallSymbolEntry::new(
        109,
        17,
        9,
        "",
        "P 2c 2",
        "P 2 2 2_1",
        "P 2 2 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        110,
        17,
        9,
        "cab",
        "P 2a 2a",
        "P 2_1 2 2",
        "P 2_1 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        111,
        17,
        9,
        "bca",
        "P 2 2b",
        "P 2 2_1 2",
        "P 2 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        112,
        18,
        9,
        "",
        "P 2 2ab",
        "P 2_1 2_1 2",
        "P 2_1 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        113,
        18,
        9,
        "cab",
        "P 2bc 2",
        "P 2 2_1 2_1",
        "P 2 2_1 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        114,
        18,
        9,
        "bca",
        "P 2ac 2ac",
        "P 2_1 2 2_1",
        "P 2_1 2 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        115,
        19,
        9,
        "",
        "P 2ac 2ab",
        "P 2_1 2_1 2_1",
        "P 2_1 2_1 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        116,
        20,
        10,
        "",
        "C 2c 2",
        "C 2 2 2_1",
        "C 2 2 2_1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        117,
        20,
        10,
        "cab",
        "A 2a 2a",
        "A 2_1 2 2",
        "A 2_1 2 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        118,
        20,
        10,
        "bca",
        "B 2 2b",
        "B 2 2_1 2",
        "B 2 2_1 2",
        Centering::B,
    ),
    HallSymbolEntry::new(119, 21, 10, "", "C 2 2", "C 2 2 2", "C 2 2 2", Centering::C),
    HallSymbolEntry::new(
        120,
        21,
        10,
        "cab",
        "A 2 2",
        "A 2 2 2",
        "A 2 2 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        121,
        21,
        10,
        "bca",
        "B 2 2",
        "B 2 2 2",
        "B 2 2 2",
        Centering::B,
    ),
    HallSymbolEntry::new(122, 22, 11, "", "F 2 2", "F 2 2 2", "F 2 2 2", Centering::F),
    HallSymbolEntry::new(123, 23, 12, "", "I 2 2", "I 2 2 2", "I 2 2 2", Centering::I),
    HallSymbolEntry::new(
        124,
        24,
        12,
        "",
        "I 2b 2c",
        "I 2_1 2_1 2_1",
        "I 2_1 2_1 2_1",
        Centering::I,
    ),
    HallSymbolEntry::new(
        125,
        25,
        13,
        "",
        "P 2 -2",
        "P m m 2",
        "P m m 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        126,
        25,
        13,
        "cab",
        "P -2 2",
        "P 2 m m",
        "P 2 m m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        127,
        25,
        13,
        "bca",
        "P -2 -2",
        "P m 2 m",
        "P m 2 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        128,
        26,
        13,
        "",
        "P 2c -2",
        "P m c 2_1",
        "P m c 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        129,
        26,
        13,
        "ba-c",
        "P 2c -2c",
        "P c m 2_1",
        "P c m 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        130,
        26,
        13,
        "cab",
        "P -2a 2a",
        "P 2_1 m a",
        "P 2_1 m a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        131,
        26,
        13,
        "-cba",
        "P -2 2a",
        "P 2_1 a m",
        "P 2_1 a m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        132,
        26,
        13,
        "bca",
        "P -2 -2b",
        "P b 2_1 m",
        "P b 2_1 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        133,
        26,
        13,
        "a-cb",
        "P -2b -2",
        "P m 2_1 b",
        "P m 2_1 b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        134,
        27,
        13,
        "",
        "P 2 -2c",
        "P c c 2",
        "P c c 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        135,
        27,
        13,
        "cab",
        "P -2a 2",
        "P 2 a a",
        "P 2 a a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        136,
        27,
        13,
        "bca",
        "P -2b -2b",
        "P b 2 b",
        "P b 2 b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        137,
        28,
        13,
        "",
        "P 2 -2a",
        "P m a 2",
        "P m a 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        138,
        28,
        13,
        "ba-c",
        "P 2 -2b",
        "P b m 2",
        "P b m 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        139,
        28,
        13,
        "cab",
        "P -2b 2",
        "P 2 m b",
        "P 2 m b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        140,
        28,
        13,
        "-cba",
        "P -2c 2",
        "P 2 c m",
        "P 2 c m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        141,
        28,
        13,
        "bca",
        "P -2c -2c",
        "P c 2 m",
        "P c 2 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        142,
        28,
        13,
        "a-cb",
        "P -2a -2a",
        "P m 2 a",
        "P m 2 a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        143,
        29,
        13,
        "",
        "P 2c -2ac",
        "P c a 2_1",
        "P c a 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        144,
        29,
        13,
        "ba-c",
        "P 2c -2b",
        "P b c 2_1",
        "P b c 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        145,
        29,
        13,
        "cab",
        "P -2b 2a",
        "P 2_1 a b",
        "P 2_1 a b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        146,
        29,
        13,
        "-cba",
        "P -2ac 2a",
        "P 2_1 c a",
        "P 2_1 c a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        147,
        29,
        13,
        "bca",
        "P -2bc -2c",
        "P c 2_1 b",
        "P c 2_1 b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        148,
        29,
        13,
        "a-cb",
        "P -2a -2ab",
        "P b 2_1 a",
        "P b 2_1 a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        149,
        30,
        13,
        "",
        "P 2 -2bc",
        "P n c 2",
        "P n c 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        150,
        30,
        13,
        "ba-c",
        "P 2 -2ac",
        "P c n 2",
        "P c n 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        151,
        30,
        13,
        "cab",
        "P -2ac 2",
        "P 2 n a",
        "P 2 n a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        152,
        30,
        13,
        "-cba",
        "P -2ab 2",
        "P 2 a n",
        "P 2 a n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        153,
        30,
        13,
        "bca",
        "P -2ab -2ab",
        "P b 2 n",
        "P b 2 n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        154,
        30,
        13,
        "a-cb",
        "P -2bc -2bc",
        "P n 2 b",
        "P n 2 b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        155,
        31,
        13,
        "",
        "P 2ac -2",
        "P m n 2_1",
        "P m n 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        156,
        31,
        13,
        "ba-c",
        "P 2bc -2bc",
        "P n m 2_1",
        "P n m 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        157,
        31,
        13,
        "cab",
        "P -2ab 2ab",
        "P 2_1 m n",
        "P 2_1 m n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        158,
        31,
        13,
        "-cba",
        "P -2 2ac",
        "P 2_1 n m",
        "P 2_1 n m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        159,
        31,
        13,
        "bca",
        "P -2 -2bc",
        "P n 2_1 m",
        "P n 2_1 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        160,
        31,
        13,
        "a-cb",
        "P -2ab -2",
        "P m 2_1 n",
        "P m 2_1 n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        161,
        32,
        13,
        "",
        "P 2 -2ab",
        "P b a 2",
        "P b a 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        162,
        32,
        13,
        "cab",
        "P -2bc 2",
        "P 2 c b",
        "P 2 c b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        163,
        32,
        13,
        "bca",
        "P -2ac -2ac",
        "P c 2 a",
        "P c 2 a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        164,
        33,
        13,
        "",
        "P 2c -2n",
        "P n a 2_1",
        "P n a 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        165,
        33,
        13,
        "ba-c",
        "P 2c -2ab",
        "P b n 2_1",
        "P b n 2_1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        166,
        33,
        13,
        "cab",
        "P -2bc 2a",
        "P 2_1 n b",
        "P 2_1 n b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        167,
        33,
        13,
        "-cba",
        "P -2n 2a",
        "P 2_1 c n",
        "P 2_1 c n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        168,
        33,
        13,
        "bca",
        "P -2n -2ac",
        "P c 2_1 n",
        "P c 2_1 n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        169,
        33,
        13,
        "a-cb",
        "P -2ac -2n",
        "P n 2_1 a",
        "P n 2_1 a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        170,
        34,
        13,
        "",
        "P 2 -2n",
        "P n n 2",
        "P n n 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        171,
        34,
        13,
        "cab",
        "P -2n 2",
        "P 2 n n",
        "P 2 n n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        172,
        34,
        13,
        "bca",
        "P -2n -2n",
        "P n 2 n",
        "P n 2 n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        173,
        35,
        14,
        "",
        "C 2 -2",
        "C m m 2",
        "C m m 2",
        Centering::C,
    ),
    HallSymbolEntry::new(
        174,
        35,
        14,
        "cab",
        "A -2 2",
        "A 2 m m",
        "A 2 m m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        175,
        35,
        14,
        "bca",
        "B -2 -2",
        "B m 2 m",
        "B m 2 m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        176,
        36,
        14,
        "",
        "C 2c -2",
        "C m c 2_1",
        "C m c 2_1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        177,
        36,
        14,
        "ba-c",
        "C 2c -2c",
        "C c m 2_1",
        "C c m 2_1",
        Centering::C,
    ),
    HallSymbolEntry::new(
        178,
        36,
        14,
        "cab",
        "A -2a 2a",
        "A 2_1 m a",
        "A 2_1 m a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        179,
        36,
        14,
        "-cba",
        "A -2 2a",
        "A 2_1 a m",
        "A 2_1 a m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        180,
        36,
        14,
        "bca",
        "B -2 -2b",
        "B b 2_1 m",
        "B b 2_1 m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        181,
        36,
        14,
        "a-cb",
        "B -2b -2",
        "B m 2_1 b",
        "B m 2_1 b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        182,
        37,
        14,
        "",
        "C 2 -2c",
        "C c c 2",
        "C c c 2",
        Centering::C,
    ),
    HallSymbolEntry::new(
        183,
        37,
        14,
        "cab",
        "A -2a 2",
        "A 2 a a",
        "A 2 a a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        184,
        37,
        14,
        "bca",
        "B -2b -2b",
        "B b 2 b",
        "B b 2 b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        185,
        38,
        15,
        "",
        "A 2 -2",
        "A m m 2",
        "A m m 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        186,
        38,
        15,
        "ba-c",
        "B 2 -2",
        "B m m 2",
        "B m m 2",
        Centering::B,
    ),
    HallSymbolEntry::new(
        187,
        38,
        15,
        "cab",
        "B -2 2",
        "B 2 m m",
        "B 2 m m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        188,
        38,
        15,
        "-cba",
        "C -2 2",
        "C 2 m m",
        "C 2 m m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        189,
        38,
        15,
        "bca",
        "C -2 -2",
        "C m 2 m",
        "C m 2 m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        190,
        38,
        15,
        "a-cb",
        "A -2 -2",
        "A m 2 m",
        "A m 2 m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        191,
        39,
        15,
        "",
        "A 2 -2b",
        "A e m 2",
        "A e m 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        192,
        39,
        15,
        "ba-c",
        "B 2 -2a",
        "B m e 2",
        "B m e 2",
        Centering::B,
    ),
    HallSymbolEntry::new(
        193,
        39,
        15,
        "cab",
        "B -2a 2",
        "B 2 e m",
        "B 2 e m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        194,
        39,
        15,
        "-cba",
        "C -2a 2",
        "C 2 m e",
        "C 2 m e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        195,
        39,
        15,
        "bca",
        "C -2a -2a",
        "C m 2 e",
        "C m 2 e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        196,
        39,
        15,
        "a-cb",
        "A -2b -2b",
        "A e 2 m",
        "A e 2 m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        197,
        40,
        15,
        "",
        "A 2 -2a",
        "A m a 2",
        "A m a 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        198,
        40,
        15,
        "ba-c",
        "B 2 -2b",
        "B b m 2",
        "B b m 2",
        Centering::B,
    ),
    HallSymbolEntry::new(
        199,
        40,
        15,
        "cab",
        "B -2b 2",
        "B 2 m b",
        "B 2 m b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        200,
        40,
        15,
        "-cba",
        "C -2c 2",
        "C 2 c m",
        "C 2 c m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        201,
        40,
        15,
        "bca",
        "C -2c -2c",
        "C c 2 m",
        "C c 2 m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        202,
        40,
        15,
        "a-cb",
        "A -2a -2a",
        "A m 2 a",
        "A m 2 a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        203,
        41,
        15,
        "",
        "A 2 -2ab",
        "A e a 2",
        "A e a 2",
        Centering::A,
    ),
    HallSymbolEntry::new(
        204,
        41,
        15,
        "ba-c",
        "B 2 -2ab",
        "B b e 2",
        "B b e 2",
        Centering::B,
    ),
    HallSymbolEntry::new(
        205,
        41,
        15,
        "cab",
        "B -2ab 2",
        "B 2 e b",
        "B 2 e b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        206,
        41,
        15,
        "-cba",
        "C -2ac 2",
        "C 2 c e",
        "C 2 c e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        207,
        41,
        15,
        "bca",
        "C -2ac -2ac",
        "C c 2 e",
        "C c 2 e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        208,
        41,
        15,
        "a-cb",
        "A -2ab -2ab",
        "A e 2 a",
        "A e 2 a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        209,
        42,
        16,
        "",
        "F 2 -2",
        "F m m 2",
        "F m m 2",
        Centering::F,
    ),
    HallSymbolEntry::new(
        210,
        42,
        16,
        "cab",
        "F -2 2",
        "F 2 m m",
        "F 2 m m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        211,
        42,
        16,
        "bca",
        "F -2 -2",
        "F m 2 m",
        "F m 2 m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        212,
        43,
        16,
        "",
        "F 2 -2d",
        "F d d 2",
        "F d d 2",
        Centering::F,
    ),
    HallSymbolEntry::new(
        213,
        43,
        16,
        "cab",
        "F -2d 2",
        "F 2 d d",
        "F 2 d d",
        Centering::F,
    ),
    HallSymbolEntry::new(
        214,
        43,
        16,
        "bca",
        "F -2d -2d",
        "F d 2 d",
        "F d 2 d",
        Centering::F,
    ),
    HallSymbolEntry::new(
        215,
        44,
        17,
        "",
        "I 2 -2",
        "I m m 2",
        "I m m 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        216,
        44,
        17,
        "cab",
        "I -2 2",
        "I 2 m m",
        "I 2 m m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        217,
        44,
        17,
        "bca",
        "I -2 -2",
        "I m 2 m",
        "I m 2 m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        218,
        45,
        17,
        "",
        "I 2 -2c",
        "I b a 2",
        "I b a 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        219,
        45,
        17,
        "cab",
        "I -2a 2",
        "I 2 c b",
        "I 2 c b",
        Centering::I,
    ),
    HallSymbolEntry::new(
        220,
        45,
        17,
        "bca",
        "I -2b -2b",
        "I c 2 a",
        "I c 2 a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        221,
        46,
        17,
        "",
        "I 2 -2a",
        "I m a 2",
        "I m a 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        222,
        46,
        17,
        "ba-c",
        "I 2 -2b",
        "I b m 2",
        "I b m 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        223,
        46,
        17,
        "cab",
        "I -2b 2",
        "I 2 m b",
        "I 2 m b",
        Centering::I,
    ),
    HallSymbolEntry::new(
        224,
        46,
        17,
        "-cba",
        "I -2c 2",
        "I 2 c m",
        "I 2 c m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        225,
        46,
        17,
        "bca",
        "I -2c -2c",
        "I c 2 m",
        "I c 2 m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        226,
        46,
        17,
        "a-cb",
        "I -2a -2a",
        "I m 2 a",
        "I m 2 a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        227,
        47,
        18,
        "",
        "-P 2 2",
        "P m m m",
        "P 2/m 2/m 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        228,
        48,
        18,
        "1",
        "P 2 2 -1n",
        "P n n n",
        "P 2/n 2/n 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        229,
        48,
        18,
        "2",
        "-P 2ab 2bc",
        "P n n n",
        "P 2/n 2/n 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        230,
        49,
        18,
        "",
        "-P 2 2c",
        "P c c m",
        "P 2/c 2/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        231,
        49,
        18,
        "cab",
        "-P 2a 2",
        "P m a a",
        "P 2/m 2/a 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        232,
        49,
        18,
        "bca",
        "-P 2b 2b",
        "P b m b",
        "P 2/b 2/m 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        233,
        50,
        18,
        "1",
        "P 2 2 -1ab",
        "P b a n",
        "P 2/b 2/a 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        234,
        50,
        18,
        "2",
        "-P 2ab 2b",
        "P b a n",
        "P 2/b 2/a 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        235,
        50,
        18,
        "1cab",
        "P 2 2 -1bc",
        "P n c b",
        "P 2/n 2/c 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        236,
        50,
        18,
        "2cab",
        "-P 2b 2bc",
        "P n c b",
        "P 2/n 2/c 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        237,
        50,
        18,
        "1bca",
        "P 2 2 -1ac",
        "P c n a",
        "P 2/c 2/n 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        238,
        50,
        18,
        "2bca",
        "-P 2a 2c",
        "P c n a",
        "P 2/c 2/n 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        239,
        51,
        18,
        "",
        "-P 2a 2a",
        "P m m a",
        "P 2_1/m 2/m 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        240,
        51,
        18,
        "ba-c",
        "-P 2b 2",
        "P m m b",
        "P 2/m 2_1/m 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        241,
        51,
        18,
        "cab",
        "-P 2 2b",
        "P b m m",
        "P 2/b 2_1/m 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        242,
        51,
        18,
        "-cba",
        "-P 2c 2c",
        "P c m m",
        "P 2/c 2/m 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        243,
        51,
        18,
        "bca",
        "-P 2c 2",
        "P m c m",
        "P 2/m 2/c 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        244,
        51,
        18,
        "a-cb",
        "-P 2 2a",
        "P m a m",
        "P 2_1/m 2/a 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        245,
        52,
        18,
        "",
        "-P 2a 2bc",
        "P n n a",
        "P 2/n 2_1/n 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        246,
        52,
        18,
        "ba-c",
        "-P 2b 2n",
        "P n n b",
        "P 2_1/n 2/n 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        247,
        52,
        18,
        "cab",
        "-P 2n 2b",
        "P b n n",
        "P 2/b 2/n 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        248,
        52,
        18,
        "-cba",
        "-P 2ab 2c",
        "P c n n",
        "P 2/c 2_1/n 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        249,
        52,
        18,
        "bca",
        "-P 2ab 2n",
        "P n c n",
        "P 2_1/n 2/c 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        250,
        52,
        18,
        "a-cb",
        "-P 2n 2bc",
        "P n a n",
        "P 2/n 2/a 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        251,
        53,
        18,
        "",
        "-P 2ac 2",
        "P m n a",
        "P 2/m 2/n 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        252,
        53,
        18,
        "ba-c",
        "-P 2bc 2bc",
        "P n m b",
        "P 2/n 2/m 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        253,
        53,
        18,
        "cab",
        "-P 2ab 2ab",
        "P b m n",
        "P 2_1/b 2/m 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        254,
        53,
        18,
        "-cba",
        "-P 2 2ac",
        "P c n m",
        "P 2_1/c 2/n 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        255,
        53,
        18,
        "bca",
        "-P 2 2bc",
        "P n c m",
        "P 2/n 2_1/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        256,
        53,
        18,
        "a-cb",
        "-P 2ab 2",
        "P m a n",
        "P 2/m 2_1/a 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        257,
        54,
        18,
        "",
        "-P 2a 2ac",
        "P c c a",
        "P 2_1/c 2/c 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        258,
        54,
        18,
        "ba-c",
        "-P 2b 2c",
        "P c c b",
        "P 2/c 2_1/c 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        259,
        54,
        18,
        "cab",
        "-P 2a 2b",
        "P b a a",
        "P 2/b 2_1/a 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        260,
        54,
        18,
        "-cba",
        "-P 2ac 2c",
        "P c a a",
        "P 2/c 2/a 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        261,
        54,
        18,
        "bca",
        "-P 2bc 2b",
        "P b c b",
        "P 2/b 2/c 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        262,
        54,
        18,
        "a-cb",
        "-P 2b 2ab",
        "P b a b",
        "P 2_1/b 2/a 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        263,
        55,
        18,
        "",
        "-P 2 2ab",
        "P b a m",
        "P 2_1/b 2_1/a 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        264,
        55,
        18,
        "cab",
        "-P 2bc 2",
        "P m c b",
        "P 2/m 2_1/c 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        265,
        55,
        18,
        "bca",
        "-P 2ac 2ac",
        "P c m a",
        "P 2_1/c 2/m 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        266,
        56,
        18,
        "",
        "-P 2ab 2ac",
        "P c c n",
        "P 2_1/c 2_1/c 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        267,
        56,
        18,
        "cab",
        "-P 2ac 2bc",
        "P n a a",
        "P 2/n 2_1/a 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        268,
        56,
        18,
        "bca",
        "-P 2bc 2ab",
        "P b n b",
        "P 2_1/b 2/n 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        269,
        57,
        18,
        "",
        "-P 2c 2b",
        "P b c m",
        "P 2/b 2_1/c 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        270,
        57,
        18,
        "ba-c",
        "-P 2c 2ac",
        "P c a m",
        "P 2_1/c 2/a 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        271,
        57,
        18,
        "cab",
        "-P 2ac 2a",
        "P m c a",
        "P 2_1/m 2/c 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        272,
        57,
        18,
        "-cba",
        "-P 2b 2a",
        "P m a b",
        "P 2_1/m 2_1/a 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        273,
        57,
        18,
        "bca",
        "-P 2a 2ab",
        "P b m a",
        "P 2_1/b 2_1/m 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        274,
        57,
        18,
        "a-cb",
        "-P 2bc 2c",
        "P c m b",
        "P 2/c 2_1/m 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        275,
        58,
        18,
        "",
        "-P 2 2n",
        "P n n m",
        "P 2_1/n 2_1/n 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        276,
        58,
        18,
        "cab",
        "-P 2n 2",
        "P m n n",
        "P 2/m 2_1/n 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        277,
        58,
        18,
        "bca",
        "-P 2n 2n",
        "P n m n",
        "P 2_1/n 2/m 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        278,
        59,
        18,
        "1",
        "P 2 2ab -1ab",
        "P m m n",
        "P 2_1/m 2_1/m 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        279,
        59,
        18,
        "2",
        "-P 2ab 2a",
        "P m m n",
        "P 2_1/m 2_1/m 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        280,
        59,
        18,
        "1cab",
        "P 2bc 2 -1bc",
        "P n m m",
        "P 2/n 2_1/m 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        281,
        59,
        18,
        "2cab",
        "-P 2c 2bc",
        "P n m m",
        "P 2/n 2_1/m 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        282,
        59,
        18,
        "1bca",
        "P 2ac 2ac -1ac",
        "P m n m",
        "P 2_1/m 2/n 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        283,
        59,
        18,
        "2bca",
        "-P 2c 2a",
        "P m n m",
        "P 2_1/m 2/n 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        284,
        60,
        18,
        "",
        "-P 2n 2ab",
        "P b c n",
        "P 2_1/b 2/c 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        285,
        60,
        18,
        "ba-c",
        "-P 2n 2c",
        "P c a n",
        "P 2/c 2_1/a 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        286,
        60,
        18,
        "cab",
        "-P 2a 2n",
        "P n c a",
        "P 2_1/n 2_1/c 2/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        287,
        60,
        18,
        "-cba",
        "-P 2bc 2n",
        "P n a b",
        "P 2_1/n 2/a 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        288,
        60,
        18,
        "bca",
        "-P 2ac 2b",
        "P b n a",
        "P 2/b 2_1/n 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        289,
        60,
        18,
        "a-cb",
        "-P 2b 2ac",
        "P c n b",
        "P 2_1/c 2_1/n 2/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        290,
        61,
        18,
        "",
        "-P 2ac 2ab",
        "P b c a",
        "P 2_1/b 2_1/c 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        291,
        61,
        18,
        "ba-c",
        "-P 2bc 2ac",
        "P c a b",
        "P 2_1/c 2_1/a 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        292,
        62,
        18,
        "",
        "-P 2ac 2n",
        "P n m a",
        "P 2_1/n 2_1/m 2_1/a",
        Centering::P,
    ),
    HallSymbolEntry::new(
        293,
        62,
        18,
        "ba-c",
        "-P 2bc 2a",
        "P m n b",
        "P 2_1/m 2_1/n 2_1/b",
        Centering::P,
    ),
    HallSymbolEntry::new(
        294,
        62,
        18,
        "cab",
        "-P 2c 2ab",
        "P b n m",
        "P 2_1/b 2_1/n 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        295,
        62,
        18,
        "-cba",
        "-P 2n 2ac",
        "P c m n",
        "P 2_1/c 2_1/m 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        296,
        62,
        18,
        "bca",
        "-P 2n 2a",
        "P m c n",
        "P 2_1/m 2_1/c 2_1/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        297,
        62,
        18,
        "a-cb",
        "-P 2c 2n",
        "P n a m",
        "P 2_1/n 2_1/a 2_1/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        298,
        63,
        19,
        "",
        "-C 2c 2",
        "C m c m",
        "C 2/m 2/c 2_1/m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        299,
        63,
        19,
        "ba-c",
        "-C 2c 2c",
        "C c m m",
        "C 2/c 2/m 2_1/m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        300,
        63,
        19,
        "cab",
        "-A 2a 2a",
        "A m m a",
        "A 2_1/m 2/m 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        301,
        63,
        19,
        "-cba",
        "-A 2 2a",
        "A m a m",
        "A 2_1/m 2/a 2/m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        302,
        63,
        19,
        "bca",
        "-B 2 2b",
        "B b m m",
        "B 2/b 2_1/m 2/m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        303,
        63,
        19,
        "a-cb",
        "-B 2b 2",
        "B m m b",
        "B 2/m 2_1/m 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        304,
        64,
        19,
        "",
        "-C 2ac 2",
        "C m c e",
        "C 2/m 2/c 2_1/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        305,
        64,
        19,
        "ba-c",
        "-C 2ac 2ac",
        "C c m e",
        "C 2/c 2/m 2_1/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        306,
        64,
        19,
        "cab",
        "-A 2ab 2ab",
        "A e m a",
        "A 2_1/e 2/m 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        307,
        64,
        19,
        "-cba",
        "-A 2 2ab",
        "A e a m",
        "A 2_1/e 2/a 2/m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        308,
        64,
        19,
        "bca",
        "-B 2 2ab",
        "B b e m",
        "B 2/b 2_1/e 2/m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        309,
        64,
        19,
        "a-cb",
        "-B 2ab 2",
        "B m e b",
        "B 2/m 2_1/e 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        310,
        65,
        19,
        "",
        "-C 2 2",
        "C m m m",
        "C 2/m 2/m 2/m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        311,
        65,
        19,
        "cab",
        "-A 2 2",
        "A m m m",
        "A 2/m 2/m 2/m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        312,
        65,
        19,
        "bca",
        "-B 2 2",
        "B m m m",
        "B 2/m 2/m 2/m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        313,
        66,
        19,
        "",
        "-C 2 2c",
        "C c c m",
        "C 2/c 2/c 2/m",
        Centering::C,
    ),
    HallSymbolEntry::new(
        314,
        66,
        19,
        "cab",
        "-A 2a 2",
        "A m a a",
        "A 2/m 2/a 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        315,
        66,
        19,
        "bca",
        "-B 2b 2b",
        "B b m b",
        "B 2/b 2/m 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        316,
        67,
        19,
        "",
        "-C 2a 2",
        "C m m e",
        "C 2/m 2/m 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        317,
        67,
        19,
        "ba-c",
        "-C 2a 2a",
        "C m m e",
        "C 2/m 2/m 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        318,
        67,
        19,
        "cab",
        "-A 2b 2b",
        "A e m m",
        "A 2/e 2/m 2/m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        319,
        67,
        19,
        "-cba",
        "-A 2 2b",
        "A e m m",
        "A 2/e 2/m 2/m",
        Centering::A,
    ),
    HallSymbolEntry::new(
        320,
        67,
        19,
        "bca",
        "-B 2 2a",
        "B m e m",
        "B 2/m 2/e 2/m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        321,
        67,
        19,
        "a-cb",
        "-B 2a 2",
        "B m e m",
        "B 2/m 2/e 2/m",
        Centering::B,
    ),
    HallSymbolEntry::new(
        322,
        68,
        19,
        "1",
        "C 2 2 -1ac",
        "C c c e",
        "C 2/c 2/c 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        323,
        68,
        19,
        "2",
        "-C 2a 2ac",
        "C c c e",
        "C 2/c 2/c 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        324,
        68,
        19,
        "1ba-c",
        "C 2 2 -1ac",
        "C c c e",
        "C 2/c 2/c 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        325,
        68,
        19,
        "2ba-c",
        "-C 2a 2c",
        "C c c e",
        "C 2/c 2/c 2/e",
        Centering::C,
    ),
    HallSymbolEntry::new(
        326,
        68,
        19,
        "1cab",
        "A 2 2 -1ab",
        "A e a a",
        "A 2/e 2/a 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        327,
        68,
        19,
        "2cab",
        "-A 2a 2b",
        "A e a a",
        "A 2/e 2/a 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        328,
        68,
        19,
        "1-cba",
        "A 2 2 -1ab",
        "A e a a",
        "A 2/e 2/a 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        329,
        68,
        19,
        "2-cba",
        "-A 2ab 2b",
        "A e a a",
        "A 2/e 2/a 2/a",
        Centering::A,
    ),
    HallSymbolEntry::new(
        330,
        68,
        19,
        "1bca",
        "B 2 2 -1ab",
        "B b e b",
        "B 2/b 2/e 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        331,
        68,
        19,
        "2bca",
        "-B 2ab 2b",
        "B b c b",
        "B 2/b 2/e 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        332,
        68,
        19,
        "1a-cb",
        "B 2 2 -1ab",
        "B b e b",
        "B 2/b 2/e 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        333,
        68,
        19,
        "2a-cb",
        "-B 2b 2ab",
        "B b e b",
        "B 2/b 2/e 2/b",
        Centering::B,
    ),
    HallSymbolEntry::new(
        334,
        69,
        20,
        "",
        "-F 2 2",
        "F m m m",
        "F 2/m 2/m 2/m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        335,
        70,
        20,
        "1",
        "F 2 2 -1d",
        "F d d d",
        "F 2/d 2/d 2/d",
        Centering::F,
    ),
    HallSymbolEntry::new(
        336,
        70,
        20,
        "2",
        "-F 2uv 2vw",
        "F d d d",
        "F 2/d 2/d 2/d",
        Centering::F,
    ),
    HallSymbolEntry::new(
        337,
        71,
        21,
        "",
        "-I 2 2",
        "I m m m",
        "I 2/m 2/m 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        338,
        72,
        21,
        "",
        "-I 2 2c",
        "I b a m",
        "I 2/b 2/a 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        339,
        72,
        21,
        "cab",
        "-I 2a 2",
        "I m c b",
        "I 2/m 2/c 2/b",
        Centering::I,
    ),
    HallSymbolEntry::new(
        340,
        72,
        21,
        "bca",
        "-I 2b 2b",
        "I c m a",
        "I 2/c 2/m 2/a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        341,
        73,
        21,
        "",
        "-I 2b 2c",
        "I b c a",
        "I 2/b 2/c 2/a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        342,
        73,
        21,
        "ba-c",
        "-I 2a 2b",
        "I c a b",
        "I 2/c 2/a 2/b",
        Centering::I,
    ),
    HallSymbolEntry::new(
        343,
        74,
        21,
        "",
        "-I 2b 2",
        "I m m a",
        "I 2/m 2/m 2/a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        344,
        74,
        21,
        "ba-c",
        "-I 2a 2a",
        "I m m b",
        "I 2/m 2/m 2/b",
        Centering::I,
    ),
    HallSymbolEntry::new(
        345,
        74,
        21,
        "cab",
        "-I 2c 2c",
        "I b m m",
        "I 2/b 2/m 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        346,
        74,
        21,
        "-cba",
        "-I 2 2b",
        "I c m m",
        "I 2/c 2/m 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        347,
        74,
        21,
        "bca",
        "-I 2 2a",
        "I m c m",
        "I 2/m 2/c 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        348,
        74,
        21,
        "a-cb",
        "-I 2c 2",
        "I m a m",
        "I 2/m 2/a 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(349, 75, 22, "", "P 4", "P 4", "P 4", Centering::P),
    HallSymbolEntry::new(350, 76, 22, "", "P 4w", "P 4_1", "P 4_1", Centering::P),
    HallSymbolEntry::new(351, 77, 22, "", "P 4c", "P 4_2", "P 4_2", Centering::P),
    HallSymbolEntry::new(352, 78, 22, "", "P 4cw", "P 4_3", "P 4_3", Centering::P),
    HallSymbolEntry::new(353, 79, 23, "", "I 4", "I 4", "I 4", Centering::I),
    HallSymbolEntry::new(354, 80, 23, "", "I 4bw", "I 4_1", "I 4_1", Centering::I),
    HallSymbolEntry::new(355, 81, 24, "", "P -4", "P -4", "P -4", Centering::P),
    HallSymbolEntry::new(356, 82, 25, "", "I -4", "I -4", "I -4", Centering::I),
    HallSymbolEntry::new(357, 83, 26, "", "-P 4", "P 4/m", "P 4/m", Centering::P),
    HallSymbolEntry::new(358, 84, 26, "", "-P 4c", "P 4_2/m", "P 4_2/m", Centering::P),
    HallSymbolEntry::new(
        359,
        85,
        26,
        "1",
        "P 4ab -1ab",
        "P 4/n",
        "P 4/n",
        Centering::P,
    ),
    HallSymbolEntry::new(360, 85, 26, "2", "-P 4a", "P 4/n", "P 4/n", Centering::P),
    HallSymbolEntry::new(
        361,
        86,
        26,
        "1",
        "P 4n -1n",
        "P 4_2/n",
        "P 4_2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        362,
        86,
        26,
        "2",
        "-P 4bc",
        "P 4_2/n",
        "P 4_2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(363, 87, 27, "", "-I 4", "I 4/m", "I 4/m", Centering::I),
    HallSymbolEntry::new(
        364,
        88,
        27,
        "1",
        "I 4bw -1bw",
        "I 4_1/a",
        "I 4_1/a",
        Centering::I,
    ),
    HallSymbolEntry::new(
        365,
        88,
        27,
        "2",
        "-I 4ad",
        "I 4_1/a",
        "I 4_1/a",
        Centering::I,
    ),
    HallSymbolEntry::new(366, 89, 28, "", "P 4 2", "P 4 2 2", "P 4 2 2", Centering::P),
    HallSymbolEntry::new(
        367,
        90,
        28,
        "",
        "P 4ab 2ab",
        "P 4 2_1 2",
        "P 4 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        368,
        91,
        28,
        "",
        "P 4w 2c",
        "P 4_1 2 2",
        "P 4_1 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        369,
        92,
        28,
        "",
        "P 4abw 2nw",
        "P 4_1 2_1 2",
        "P 4_1 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        370,
        93,
        28,
        "",
        "P 4c 2",
        "P 4_2 2 2",
        "P 4_2 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        371,
        94,
        28,
        "",
        "P 4n 2n",
        "P 4_2 2_1 2",
        "P 4_2 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        372,
        95,
        28,
        "",
        "P 4cw 2c",
        "P 4_3 2 2",
        "P 4_3 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        373,
        96,
        28,
        "",
        "P 4nw 2abw",
        "P 4_3 2_1 2",
        "P 4_3 2_1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(374, 97, 29, "", "I 4 2", "I 4 2 2", "I 4 2 2", Centering::I),
    HallSymbolEntry::new(
        375,
        98,
        29,
        "",
        "I 4bw 2bw",
        "I 4_1 2 2",
        "I 4_1 2 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        376,
        99,
        30,
        "",
        "P 4 -2",
        "P 4 m m",
        "P 4 m m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        377,
        100,
        30,
        "",
        "P 4 -2ab",
        "P 4 b m",
        "P 4 b m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        378,
        101,
        30,
        "",
        "P 4c -2c",
        "P 4_2 c m",
        "P 4_2 c m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        379,
        102,
        30,
        "",
        "P 4n -2n",
        "P 4_2 n m",
        "P 4_2 n m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        380,
        103,
        30,
        "",
        "P 4 -2c",
        "P 4 c c",
        "P 4 c c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        381,
        104,
        30,
        "",
        "P 4 -2n",
        "P 4 n c",
        "P 4 n c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        382,
        105,
        30,
        "",
        "P 4c -2",
        "P 4_2 m c",
        "P 4_2 m c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        383,
        106,
        30,
        "",
        "P 4c -2ab",
        "P 4_2 b c",
        "P 4_2 b c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        384,
        107,
        31,
        "",
        "I 4 -2",
        "I 4 m m",
        "I 4 m m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        385,
        108,
        31,
        "",
        "I 4 -2c",
        "I 4 c m",
        "I 4 c m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        386,
        109,
        31,
        "",
        "I 4bw -2",
        "I 4_1 m d",
        "I 4_1 m d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        387,
        110,
        31,
        "",
        "I 4bw -2c",
        "I 4_1 c d",
        "I 4_1 c d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        388,
        111,
        32,
        "",
        "P -4 2",
        "P -4 2 m",
        "P -4 2 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        389,
        112,
        32,
        "",
        "P -4 2c",
        "P -4 2 c",
        "P -4 2 c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        390,
        113,
        32,
        "",
        "P -4 2ab",
        "P -4 2_1 m",
        "P -4 2_1 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        391,
        114,
        32,
        "",
        "P -4 2n",
        "P -4 2_1 c",
        "P -4 2_1 c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        392,
        115,
        33,
        "",
        "P -4 -2",
        "P -4 m 2",
        "P -4 m 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        393,
        116,
        33,
        "",
        "P -4 -2c",
        "P -4 c 2",
        "P -4 c 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        394,
        117,
        33,
        "",
        "P -4 -2ab",
        "P -4 b 2",
        "P -4 b 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        395,
        118,
        33,
        "",
        "P -4 -2n",
        "P -4 n 2",
        "P -4 n 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        396,
        119,
        34,
        "",
        "I -4 -2",
        "I -4 m 2",
        "I -4 m 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        397,
        120,
        34,
        "",
        "I -4 -2c",
        "I -4 c 2",
        "I -4 c 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        398,
        121,
        35,
        "",
        "I -4 2",
        "I -4 2 m",
        "I -4 2 m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        399,
        122,
        35,
        "",
        "I -4 2bw",
        "I -4 2 d",
        "I -4 2 d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        400,
        123,
        36,
        "",
        "-P 4 2",
        "P 4/m m m",
        "P 4/m 2/m 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        401,
        124,
        36,
        "",
        "-P 4 2c",
        "P 4/m c c",
        "P 4/m 2/c 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        402,
        125,
        36,
        "1",
        "P 4 2 -1ab",
        "P 4/n b m",
        "P 4/n 2/b 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        403,
        125,
        36,
        "2",
        "-P 4a 2b",
        "P 4/n b m",
        "P 4/n 2/b 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        404,
        126,
        36,
        "1",
        "P 4 2 -1n",
        "P 4/n n c",
        "P 4/n 2/n 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        405,
        126,
        36,
        "2",
        "-P 4a 2bc",
        "P 4/n n c",
        "P 4/n 2/n 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        406,
        127,
        36,
        "",
        "-P 4 2ab",
        "P 4/m b m",
        "P 4/m 2_1/b m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        407,
        128,
        36,
        "",
        "-P 4 2n",
        "P 4/m n c",
        "P 4/m 2_1/n c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        408,
        129,
        36,
        "1",
        "P 4ab 2ab -1ab",
        "P 4/n m m",
        "P 4/n 2_1/m m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        409,
        129,
        36,
        "2",
        "-P 4a 2a",
        "P 4/n m m",
        "P 4/n 2_1/m m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        410,
        130,
        36,
        "1",
        "P 4ab 2n -1ab",
        "P 4/n c c",
        "P 4/n 2_1/c c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        411,
        130,
        36,
        "2",
        "-P 4a 2ac",
        "P 4/n c c",
        "P 4/n 2_1/c c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        412,
        131,
        36,
        "",
        "-P 4c 2",
        "P 4_2/m m c",
        "P 4_2/m 2/m 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        413,
        132,
        36,
        "",
        "-P 4c 2c",
        "P 4_2/m c m",
        "P 4_2/m 2/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        414,
        133,
        36,
        "1",
        "P 4n 2c -1n",
        "P 4_2/n b c",
        "P 4_2/n 2/b 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        415,
        133,
        36,
        "2",
        "-P 4ac 2b",
        "P 4_2/n b c",
        "P 4_2/n 2/b 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        416,
        134,
        36,
        "1",
        "P 4n 2 -1n",
        "P 4_2/n n m",
        "P 4_2/n 2/n 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        417,
        134,
        36,
        "2",
        "-P 4ac 2bc",
        "P 4_2/n n m",
        "P 4_2/n 2/n 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        418,
        135,
        36,
        "",
        "-P 4c 2ab",
        "P 4_2/m b c",
        "P 4_2/m 2_1/b 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        419,
        136,
        36,
        "",
        "-P 4n 2n",
        "P 4_2/m n m",
        "P 4_2/m 2_1/n 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        420,
        137,
        36,
        "1",
        "P 4n 2n -1n",
        "P 4_2/n m c",
        "P 4_2/n 2_1/m 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        421,
        137,
        36,
        "2",
        "-P 4ac 2a",
        "P 4_2/n m c",
        "P 4_2/n 2_1/m 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        422,
        138,
        36,
        "1",
        "P 4n 2ab -1n",
        "P 4_2/n c m",
        "P 4_2/n 2_1/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        423,
        138,
        36,
        "2",
        "-P 4ac 2ac",
        "P 4_2/n c m",
        "P 4_2/n 2_1/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        424,
        139,
        37,
        "",
        "-I 4 2",
        "I 4/m m m",
        "I 4/m 2/m 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        425,
        140,
        37,
        "",
        "-I 4 2c",
        "I 4/m c m",
        "I 4/m 2/c 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        426,
        141,
        37,
        "1",
        "I 4bw 2bw -1bw",
        "I 4_1/a m d",
        "I 4_1/a 2/m 2/d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        427,
        141,
        37,
        "2",
        "-I 4bd 2",
        "I 4_1/a m d",
        "I 4_1/a 2/m 2/d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        428,
        142,
        37,
        "1",
        "I 4bw 2aw -1bw",
        "I 4_1/a c d",
        "I 4_1/a 2/c 2/d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        429,
        142,
        37,
        "2",
        "-I 4bd 2c",
        "I 4_1/a c d",
        "I 4_1/a 2/c 2/d",
        Centering::I,
    ),
    HallSymbolEntry::new(430, 143, 38, "", "P 3", "P 3", "P 3", Centering::P),
    HallSymbolEntry::new(431, 144, 38, "", "P 31", "P 3_1", "P 3_1", Centering::P),
    HallSymbolEntry::new(432, 145, 38, "", "P 32", "P 3_2", "P 3_2", Centering::P),
    HallSymbolEntry::new(433, 146, 39, "H", "R 3", "R 3", "R 3", Centering::R),
    HallSymbolEntry::new(434, 146, 39, "R", "P 3*", "R 3", "R 3", Centering::P),
    HallSymbolEntry::new(435, 147, 40, "", "-P 3", "P -3", "P -3", Centering::P),
    HallSymbolEntry::new(436, 148, 41, "H", "-R 3", "R -3", "R -3", Centering::R),
    HallSymbolEntry::new(437, 148, 41, "R", "-P 3*", "R -3", "R -3", Centering::P),
    HallSymbolEntry::new(
        438,
        149,
        42,
        "",
        "P 3 2",
        "P 3 1 2",
        "P 3 1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        439,
        150,
        43,
        "",
        "P 3 2=",
        "P 3 2 1",
        "P 3 2 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        440,
        151,
        42,
        "",
        "P 31 2 (0 0 4)",
        "P 3_1 1 2",
        "P 3_1 1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        441,
        152,
        43,
        "",
        "P 31 2=",
        "P 3_1 2 1",
        "P 3_1 2 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        442,
        153,
        42,
        "",
        "P 32 2 (0 0 2)",
        "P 3_2 1 2",
        "P 3_2 1 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        443,
        154,
        43,
        "",
        "P 32 2=",
        "P 3_2 2 1",
        "P 3_2 2 1",
        Centering::P,
    ),
    HallSymbolEntry::new(444, 155, 44, "H", "R 3 2=", "R 3 2", "R 3 2", Centering::R),
    HallSymbolEntry::new(445, 155, 44, "R", "P 3* 2", "R 3 2", "R 3 2", Centering::P),
    HallSymbolEntry::new(
        446,
        156,
        45,
        "",
        "P 3 -2=",
        "P 3 m 1",
        "P 3 m 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        447,
        157,
        46,
        "",
        "P 3 -2",
        "P 3 1 m",
        "P 3 1 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        448,
        158,
        45,
        "",
        "P 3 -2=c",
        "P 3 c 1",
        "P 3 c 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        449,
        159,
        46,
        "",
        "P 3 -2c",
        "P 3 1 c",
        "P 3 1 c",
        Centering::P,
    ),
    HallSymbolEntry::new(450, 160, 47, "H", "R 3 -2=", "R 3 m", "R 3 m", Centering::R),
    HallSymbolEntry::new(451, 160, 47, "R", "P 3* -2", "R 3 m", "R 3 m", Centering::P),
    HallSymbolEntry::new(
        452,
        161,
        47,
        "H",
        "R 3 -2=c",
        "R 3 c",
        "R 3 c",
        Centering::R,
    ),
    HallSymbolEntry::new(
        453,
        161,
        47,
        "R",
        "P 3* -2n",
        "R 3 c",
        "R 3 c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        454,
        162,
        48,
        "",
        "-P 3 2",
        "P -3 1 m",
        "P -3 1 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        455,
        163,
        48,
        "",
        "-P 3 2c",
        "P -3 1 c",
        "P -3 1 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        456,
        164,
        49,
        "",
        "-P 3 2=",
        "P -3 m 1",
        "P -3 2/m 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        457,
        165,
        49,
        "",
        "-P 3 2=c",
        "P -3 c 1",
        "P -3 2/c 1",
        Centering::P,
    ),
    HallSymbolEntry::new(
        458,
        166,
        50,
        "H",
        "-R 3 2=",
        "R -3 m",
        "R -3 2/m",
        Centering::R,
    ),
    HallSymbolEntry::new(
        459,
        166,
        50,
        "R",
        "-P 3* 2",
        "R -3 m",
        "R -3 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        460,
        167,
        50,
        "H",
        "-R 3 2=c",
        "R -3 c",
        "R -3 2/c",
        Centering::R,
    ),
    HallSymbolEntry::new(
        461,
        167,
        50,
        "R",
        "-P 3* 2n",
        "R -3 c",
        "R -3 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(462, 168, 51, "", "P 6", "P 6", "P 6", Centering::P),
    HallSymbolEntry::new(463, 169, 51, "", "P 61", "P 6_1", "P 6_1", Centering::P),
    HallSymbolEntry::new(464, 170, 51, "", "P 65", "P 6_5", "P 6_5", Centering::P),
    HallSymbolEntry::new(465, 171, 51, "", "P 62", "P 6_2", "P 6_2", Centering::P),
    HallSymbolEntry::new(466, 172, 51, "", "P 64", "P 6_4", "P 6_4", Centering::P),
    HallSymbolEntry::new(467, 173, 51, "", "P 6c", "P 6_3", "P 6_3", Centering::P),
    HallSymbolEntry::new(468, 174, 52, "", "P -6", "P -6", "P -6", Centering::P),
    HallSymbolEntry::new(469, 175, 53, "", "-P 6", "P 6/m", "P 6/m", Centering::P),
    HallSymbolEntry::new(
        470,
        176,
        53,
        "",
        "-P 6c",
        "P 6_3/m",
        "P 6_3/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        471,
        177,
        54,
        "",
        "P 6 2",
        "P 6 2 2",
        "P 6 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        472,
        178,
        54,
        "",
        "P 61 2 (0 0 5)",
        "P 6_1 2 2",
        "P 6_1 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        473,
        179,
        54,
        "",
        "P 65 2 (0 0 1)",
        "P 6_5 2 2",
        "P 6_5 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        474,
        180,
        54,
        "",
        "P 62 2 (0 0 4)",
        "P 6_2 2 2",
        "P 6_2 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        475,
        181,
        54,
        "",
        "P 64 2 (0 0 2)",
        "P 6_4 2 2",
        "P 6_4 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        476,
        182,
        54,
        "",
        "P 6c 2c",
        "P 6_3 2 2",
        "P 6_3 2 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        477,
        183,
        55,
        "",
        "P 6 -2",
        "P 6 m m",
        "P 6 m m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        478,
        184,
        55,
        "",
        "P 6 -2c",
        "P 6 c c",
        "P 6 c c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        479,
        185,
        55,
        "",
        "P 6c -2",
        "P 6_3 c m",
        "P 6_3 c m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        480,
        186,
        55,
        "",
        "P 6c -2c",
        "P 6_3 m c",
        "P 6_3 m c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        481,
        187,
        57,
        "",
        "P -6 2",
        "P -6 m 2",
        "P -6 m 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        482,
        188,
        57,
        "",
        "P -6c 2",
        "P -6 c 2",
        "P -6 c 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        483,
        189,
        56,
        "",
        "P -6 -2",
        "P -6 2 m",
        "P -6 2 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        484,
        190,
        56,
        "",
        "P -6c -2c",
        "P -6 2 c",
        "P -6 2 c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        485,
        191,
        58,
        "",
        "-P 6 2",
        "P 6/m m m",
        "P 6/m 2/m 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        486,
        192,
        58,
        "",
        "-P 6 2c",
        "P 6/m c c",
        "P 6/m 2/c 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(
        487,
        193,
        58,
        "",
        "-P 6c 2",
        "P 6_3/m c m",
        "P 6_3/m 2/c 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        488,
        194,
        58,
        "",
        "-P 6c 2c",
        "P 6_3/m m c",
        "P 6_3/m 2/m 2/c",
        Centering::P,
    ),
    HallSymbolEntry::new(489, 195, 59, "", "P 2 2 3", "P 2 3", "P 2 3", Centering::P),
    HallSymbolEntry::new(490, 196, 60, "", "F 2 2 3", "F 2 3", "F 2 3", Centering::F),
    HallSymbolEntry::new(491, 197, 61, "", "I 2 2 3", "I 2 3", "I 2 3", Centering::I),
    HallSymbolEntry::new(
        492,
        198,
        59,
        "",
        "P 2ac 2ab 3",
        "P 2_1 3",
        "P 2_1 3",
        Centering::P,
    ),
    HallSymbolEntry::new(
        493,
        199,
        61,
        "",
        "I 2b 2c 3",
        "I 2_1 3",
        "I 2_1 3",
        Centering::I,
    ),
    HallSymbolEntry::new(
        494,
        200,
        62,
        "",
        "-P 2 2 3",
        "P m -3",
        "P 2/m -3",
        Centering::P,
    ),
    HallSymbolEntry::new(
        495,
        201,
        62,
        "1",
        "P 2 2 3 -1n",
        "P n -3",
        "P 2/n -3",
        Centering::P,
    ),
    HallSymbolEntry::new(
        496,
        201,
        62,
        "2",
        "-P 2ab 2bc 3",
        "P n -3",
        "P 2/n -3",
        Centering::P,
    ),
    HallSymbolEntry::new(
        497,
        202,
        63,
        "",
        "-F 2 2 3",
        "F m -3",
        "F 2/m -3",
        Centering::F,
    ),
    HallSymbolEntry::new(
        498,
        203,
        63,
        "1",
        "F 2 2 3 -1d",
        "F d -3",
        "F 2/d -3",
        Centering::F,
    ),
    HallSymbolEntry::new(
        499,
        203,
        63,
        "2",
        "-F 2uv 2vw 3",
        "F d -3",
        "F 2/d -3",
        Centering::F,
    ),
    HallSymbolEntry::new(
        500,
        204,
        64,
        "",
        "-I 2 2 3",
        "I m -3",
        "I 2/m -3",
        Centering::I,
    ),
    HallSymbolEntry::new(
        501,
        205,
        62,
        "",
        "-P 2ac 2ab 3",
        "P a -3",
        "P 2_1/a -3",
        Centering::P,
    ),
    HallSymbolEntry::new(
        502,
        206,
        64,
        "",
        "-I 2b 2c 3",
        "I a -3",
        "I 2_1/a -3",
        Centering::I,
    ),
    HallSymbolEntry::new(
        503,
        207,
        65,
        "",
        "P 4 2 3",
        "P 4 3 2",
        "P 4 3 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        504,
        208,
        65,
        "",
        "P 4n 2 3",
        "P 4_2 3 2",
        "P 4_2 3 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        505,
        209,
        66,
        "",
        "F 4 2 3",
        "F 4 3 2",
        "F 4 3 2",
        Centering::F,
    ),
    HallSymbolEntry::new(
        506,
        210,
        66,
        "",
        "F 4d 2 3",
        "F 4_1 3 2",
        "F 4_1 3 2",
        Centering::F,
    ),
    HallSymbolEntry::new(
        507,
        211,
        67,
        "",
        "I 4 2 3",
        "I 4 3 2",
        "I 4 3 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        508,
        212,
        65,
        "",
        "P 4acd 2ab 3",
        "P 4_3 3 2",
        "P 4_3 3 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        509,
        213,
        65,
        "",
        "P 4bd 2ab 3",
        "P 4_1 3 2",
        "P 4_1 3 2",
        Centering::P,
    ),
    HallSymbolEntry::new(
        510,
        214,
        67,
        "",
        "I 4bd 2c 3",
        "I 4_1 3 2",
        "I 4_1 3 2",
        Centering::I,
    ),
    HallSymbolEntry::new(
        511,
        215,
        68,
        "",
        "P -4 2 3",
        "P -4 3 m",
        "P -4 3 m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        512,
        216,
        69,
        "",
        "F -4 2 3",
        "F -4 3 m",
        "F -4 3 m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        513,
        217,
        70,
        "",
        "I -4 2 3",
        "I -4 3 m",
        "I -4 3 m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        514,
        218,
        68,
        "",
        "P -4n 2 3",
        "P -4 3 n",
        "P -4 3 n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        515,
        219,
        69,
        "",
        "F -4a 2 3",
        "F -4 3 c",
        "F -4 3 c",
        Centering::F,
    ),
    HallSymbolEntry::new(
        516,
        220,
        70,
        "",
        "I -4bd 2c 3",
        "I -4 3 d",
        "I -4 3 d",
        Centering::I,
    ),
    HallSymbolEntry::new(
        517,
        221,
        71,
        "",
        "-P 4 2 3",
        "P m -3 m",
        "P 4/m -3 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        518,
        222,
        71,
        "1",
        "P 4 2 3 -1n",
        "P n -3 n",
        "P 4/n -3 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        519,
        222,
        71,
        "2",
        "-P 4a 2bc 3",
        "P n -3 n",
        "P 4/n -3 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        520,
        223,
        71,
        "",
        "-P 4n 2 3",
        "P m -3 n",
        "P 4_2/m -3 2/n",
        Centering::P,
    ),
    HallSymbolEntry::new(
        521,
        224,
        71,
        "1",
        "P 4n 2 3 -1n",
        "P n -3 m",
        "P 4_2/n -3 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        522,
        224,
        71,
        "2",
        "-P 4bc 2bc 3",
        "P n -3 m",
        "P 4_2/n -3 2/m",
        Centering::P,
    ),
    HallSymbolEntry::new(
        523,
        225,
        72,
        "",
        "-F 4 2 3",
        "F m -3 m",
        "F 4/m -3 2/m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        524,
        226,
        72,
        "",
        "-F 4a 2 3",
        "F m -3 c",
        "F 4/m -3 2/c",
        Centering::F,
    ),
    HallSymbolEntry::new(
        525,
        227,
        72,
        "1",
        "F 4d 2 3 -1d",
        "F d -3 m",
        "F 4_1/d -3 2/m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        526,
        227,
        72,
        "2",
        "-F 4vw 2vw 3",
        "F d -3 m",
        "F 4_1/d -3 2/m",
        Centering::F,
    ),
    HallSymbolEntry::new(
        527,
        228,
        72,
        "1",
        "F 4d 2 3 -1ad",
        "F d -3 c",
        "F 4_1/d -3 2/c",
        Centering::F,
    ),
    HallSymbolEntry::new(
        528,
        228,
        72,
        "2",
        "-F 4ud 2vw 3",
        "F d -3 c",
        "F 4_1/d -3 2/c",
        Centering::F,
    ),
    HallSymbolEntry::new(
        529,
        229,
        73,
        "",
        "-I 4 2 3",
        "I m -3 m",
        "I 4/m -3 2/m",
        Centering::I,
    ),
    HallSymbolEntry::new(
        530,
        230,
        73,
        "",
        "-I 4bd 2c 3",
        "I a -3 d",
        "I 4_1/a -3 2/d",
        Centering::I,
    ),
];
